module MtrMonitor

  # represents one hop in the MTR report
  #
  # example hop for `mtr --report github.com`:
  # 12.|-- github-ic-318125-ash-b1.c  0.0%    10  136.2 136.2 135.0 140.7   1.5

  class Hop
    def self.parse(line)
      return unless line =~ /\|--/

      new(*line.split(" ")[1..-1])
    end

    attr_reader :name, :loss, :snt, :last, :avg, :best, :worst, :std_dev

    def initialize(name, loss, snt, last, avg, best, worst, std_dev)
      @name    = name
      @loss    = loss.to_f
      @snt     = snt.to_i
      @last    = last.to_f
      @avg     = avg.to_f
      @best    = best.to_f
      @worst   = worst.to_f
      @std_dev = std_dev.to_f
    end
  end

end
