module MtrMonitor
  class LogDna

    def self.submit(*args)
      new(*args).submit
    end

    def initialize(route_name, logdna_ingestion_key, local_log_path, host_ip_address, s3_url, hostname, logger)
      config = {
        :ip => host_ip_address,
        :app => "mtr-monitor",
        :level => "INFO"
      }

      @route_name = route_name
      @s3_url     = s3_url
      @hostname   = hostname

      @mtr_log = File.read(local_log_path)
      @logdna  = Logdna::Ruby.new(logdna_ingestion_key, config)
      @logger  = logger
    end

    def submit
      msg = "Route: #{@route_name}, Host: #{@hostname}, Tier1: #{tier1_provider}, s3: #{@s3_url}"

      @logdna.log(msg)
      @logger.info("Emitted to LogDNA: #{msg}")
    end

    private

    def tier1_provider
      @tier1_provider ||= if @mtr_log.include?("telia.net")
                            "Telia"
                          elsif @mtr_log.include?("gtt.net")
                            "GTT"
                          elsif @mtr_log.include?("ntt.net")
                            "NTT"
                          elsif @mtr_log.include?("core-backbone.com")
                            "Core_Backbone"
                          else
                            "Unknown"
                          end
    end

  end
end
